@@ -1,8 +1,8 @@
 simulateoutbreak <-
-function(init.sus, inf.rate, rem.rate, mut.rate, nmat=NULL, equi.pop=10000, 
+function(init.sus, inf.rate, rem.rate, mut.rate, nmat=NULL, equi.pop=10000, shape=flat,
          init.inf=1, inoc.size=1, samples.per.time=1, samp.schedule="random", 
          samp.freq=500, full=FALSE, mincases=1, feedback=500, glen=100000, 
-         ref.strain=NULL) {
+         ref.strain=NULL, ...) {
   
   # WARNINGS
   
@@ -39,6 +39,9 @@ function(init.sus, inf.rate, rem.rate, mut.rate, nmat=NULL, equi.pop=10000,
   if (mut.rate<0 || mut.rate>=1) {
     stop("Mutation rate must be between 0 and 1")
   }
+  if (!is.function(shape)) {
+    stop("'shape' must be a function")
+  } 
   if (!is.null(nmat)) {
     if (!is.matrix(nmat)) {
       stop("nmat must be a matrix")
@@ -78,7 +81,10 @@ function(init.sus, inf.rate, rem.rate, mut.rate, nmat=NULL, equi.pop=10000,
     tot.inf <- init.inf
     inf.ID <- 1:init.inf
     if (samp.schedule=="random") {
-      sample.times <- sample(1:(rec.times[1]-1),init.inf, replace=TRUE) # vector of sampling times
+      sample.times <- NULL
+      for (i in 1:init.inf) {
+        sample.times <- c(sample.times, sample(1:(rec.times[i]-1),1)) # vector of sampling times
+      }
     } else {
       sample.times <- rep(samp.freq, init.inf)
     }
@@ -252,7 +258,7 @@ function(init.sus, inf.rate, rem.rate, mut.rate, nmat=NULL, equi.pop=10000,
       }
       for (i in cinf) {
         pop.size <- sum(freq.log[[i]])
-        death.prob <- 0.5 + 0.5*(pop.size-equi.pop)/equi.pop
+        death.prob <- min(0.5 + 0.5*(pop.size-shape(time,span=rec.times[i]-inf.times[i]+1,equi.pop,...))/shape(time,span=rec.times[i]-inf.times[i]+1,equi.pop,...),1)
         if (length(freq.log)==0 || sum(is.na(freq.log))>0 || death.prob>1 || death.prob<0) {
           cat("deathprob=", death.prob, "\npop.size=", pop.size, "\nequi.pop=", equi.pop, "\nFreq.log:\n")
           if (length(freq.log)>0) {
